@@ -1,4 +1,4 @@
-// Copyright (c) 2021 GreenYun Organization
+// Copyright (c) 2022 GreenYun Organization
 //
 // This software is released under the MIT License.
 // https://opensource.org/licenses/MIT
@@ -10,6 +10,3 @@ pub use self::{data_structure::*, display::*, lang::Lang};
 mod data_structure;
 mod display;
 mod lang;
-
-#[macro_use]
-mod r#macro;
