@@ -1,4 +1,4 @@
-// Copyright (c) 2021 GreenYun Organization
+// Copyright (c) 2022 GreenYun Organization
 //
 // This software is released under the MIT License.
 // https://opensource.org/licenses/MIT
@@ -8,8 +8,10 @@
 use chrono::{DateTime, FixedOffset};
 use serde::Deserialize;
 
+use crate::fetch::impl_api;
+
 /// A tip with `desc`ription and `update_time`.
-#[derive(Debug, Deserialize)]
+#[derive(Clone, Debug, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Tip {
     /// May be missing if the value is null or not available.
@@ -17,15 +19,14 @@ pub struct Tip {
 
     /// May be missing if the value is null or not available.
     #[serde(default)]
-    #[serde(deserialize_with = "crate::internal::deserialize::deserialize_to_option_datetime")]
     pub update_time: Option<DateTime<FixedOffset>>,
 }
 
 /// None or more tips.
-#[derive(Debug, Deserialize)]
+#[derive(Clone, Debug, Deserialize)]
 pub struct Tips {
     #[serde(rename = "swt")]
     pub tips: Vec<Tip>,
 }
 
-impl_api!(Tips, swt);
+impl_api!(Tips, weather, swt);
