@@ -1,4 +1,4 @@
-// Copyright (c) 2021 GreenYun Organization
+// Copyright (c) 2022 GreenYun Organization
 //
 // This software is released under the MIT License.
 // https://opensource.org/licenses/MIT
@@ -14,4 +14,6 @@ mod code;
 pub mod info;
 pub mod summary;
 
+#[cfg(feature = "test")]
+#[cfg(test)]
 mod test;
